VoucherGenerationSummaryViewModel class

Inheritance

Properties

buildParams V2VoucherGenerationSummaryBuilder
final
cardData TransactionDetails?
latefinal
coinDiscountAvailable bool
no setter
coinsDiscount double?
no setter
couponDiscountAvailable bool
no setter
currentPaymentMode → SimpleValueCubit<PaymentMode>
final
deviceDetailJob → DeferredJob
final
discountedAmount double
no setter
discountTypeText String
no setter
doesNotIncludeWalletDiscountText String
no setter
handleAllowedUPIAppsJob → DeferredJob<(List<String>, bool, bool)>
final
handleCompleteOrderJob → DeferredJob<_RedemptionResponseData>
final
handleInitOrderJob → DeferredJob<_RedemptionResponseData>
final
handleUPIInstalledAppsJob → DeferredJob<List<UPIApp>>
final
hashCode int
The hash code for this object.
no setterinherited
includesWalletDiscountText String
no setter
initializer → DeferredJob<VoucherGenerationSummaryViewState>
latefinalinherited
installedUPIApps List<UPIApp>
getter/setter pair
isCardDown bool
latefinal
isClosed bool
Whether the bloc is closed.
no setterinherited
isCollectRequestEnabled bool
getter/setter pair
isInitialized bool
no setterinherited
isUpiDown bool
latefinal
isWalletActive bool
no setter
isWalletDown bool
latefinal
listable ValueListenable<HubbleViewState>
no setterinherited
pgCouponAvailable bool
no setter
proDiscountAvailable bool
no setter
referralDiscountAvailable bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldShowAllUPIAppsOption bool
no setter
showAllUPIAppsOption bool
getter/setter pair
snack → HubbleSnackBarState
no setterinherited
state → SimpleValue<HubbleViewState>
The current state.
no setterinherited
stream Stream<SimpleValue<HubbleViewState>>
The current stream of states.
no setterinherited
upiCardTitle String
no setter
upiData TransactionDetails?
latefinal
value ↔ HubbleViewState
getter/setter pairinherited
viewState VoucherGenerationSummaryViewState
no setterinherited
walletCardTitle String
no setter
walletData TransactionDetails?
latefinal

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
amountToBePaid(TransactionDetails transactionDetails) double
build(Widget builder(BuildContext context, HubbleViewState value), {bool when(HubbleViewState, HubbleViewState)?}) Widget
inherited
buildAs<Z>(Widget builder(BuildContext context, Z value), {bool when(HubbleViewState, HubbleViewState)?}) Widget
inherited
buildIfNotEqual(Widget builder(BuildContext context, HubbleViewState value)) Widget
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
defer<X>(dynamic object, void callback(X object)) → void
inherited
deferredScrollController({bool keepScrollOffset = true, double initialScrollOffset = 0.0}) ScrollController
inherited
deferStream(StreamSubscription subscription) → void
inherited
emit(SimpleValue<HubbleViewState> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
findInstalledApps(String orderId) Future<List<UPIApp>>
fromContext(BuildContext context, {bool listen = true}) → SimpleValueCubit<HubbleViewState>
inherited
handleAddMoneyClick() → void
handlePop() Future<bool>
hydrate() Future<void>
inherited
hydrateHeadless() Future<VoucherGenerationSummaryViewState>
inherited
init() Future<VoucherGenerationSummaryViewState>
override
initializeV2Payments() Future<void>
initPgRedemption({required PaymentMode paymentMode}) Future<void>
initWalletRedemption() Future<void>
inject<Injectable extends Object>() → Injectable
inherited
launchUPIApp(String selectedApp) → void
maybePop({Object? result}) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAfterInit() → void
inherited
onChange(Change<SimpleValue<HubbleViewState>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onClickContinue() Future<void>
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onInitFailure() → void
inherited
reactive<F>(F initialValue) → SimpleValueCubit<F>
inherited
reInit() → void
inherited
setValue(HubbleViewState value) → void
inherited
showInModal<ModalResult>(WidgetBuilder builder, {required String routeName, Map<String, dynamic>? eventProps, bool expand = false}) Future<ModalResult?>
inherited
softReInit() Future<VoucherGenerationSummaryViewState>
inherited
toString() String
A string representation of this object.
inherited
update(HubbleViewState predicate(HubbleViewState value)) → void
inherited
updateViewState(VoucherGenerationSummaryViewState predicate(VoucherGenerationSummaryViewState value)) → void
inherited
v2PaymentOptionModalCreditCardPaymentEvent() → void
v2PaymentOptionModalUPIEvent(String appName) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited